@@ -5,13 +5,13 @@ class World
     def add_user(name)
       transaction do
 	raise 'already regsitered' if self[name]
-	self[name] = User.knew(name)
+	self[name] = User.new(name)
       end
     end
   end
 
   class User < PRb::PRbRoot
-    def init(nm)
+    def initialize(nm)
       self.name = nm
     end
     prb_attr :name, :email
@@ -26,7 +26,7 @@ class World
     root.transaction do
       world = root[$0]
       unless world
-	world = UserList.knew
+	world = UserList.new
 	root[$0] = world
       end
       @world = world
