@@ -1,7 +1,7 @@
 require 'prb/prb'
 
 class Item < PRb::PRbObject
-  def init(nm)
+  def initialize(nm)
     self.name = nm
   end
   prb_attr :name, :ary
@@ -20,7 +20,7 @@ def main
   50.times do
     x = nil
     root.transaction do
-      x = Item.knew('seki')
+      x = Item.new('seki')
       root.add(x)
       x.ary = []
     end
