@@ -158,21 +158,26 @@ module PRb
   class PRbObject
     include PRbO
 
-    def self.knew(*args)
-      if PRb === args[0]
+    def self.new(*args)
+      if PRb::Store === args[0]
 	prb = args.shift
       else
 	prb = PRb.primary
       end
       prb.transaction do
 	it = prb.alloc(self)
-	it.init(*args)
-	it
+        it.instance_eval { initialize(*args) }
+        it
       end
     end
-    def init(*args); end
-      
-    def initialize(prb, ref)
+
+    def self.prb_new(prb, ref)
+      obj = self.allocate
+      obj.prb_initialize(prb, ref)
+      obj
+    end
+
+    def prb_initialize(prb, ref)
       @prb = prb
       @ref = ref
     end
@@ -500,7 +505,7 @@ module PRb
       @prbseq = SeqQueue.new(pool, 'object_seq')
       
       @root_id = 8
-      @root = PRbRoot.new(self, @root_id)
+      @root = PRbRoot.prb_new(self, @root_id)
       
       @db_name = @pool.db_name
       self.class[@db_name] = self
@@ -774,7 +779,7 @@ EOQ
     end
     
     def alloc(klass)
-      klass.new(self, alloc_obj(klass, nil))
+      klass.prb_new(self, alloc_obj(klass, nil))
     end
 
     def gc
@@ -838,6 +843,16 @@ SQL
     def alloc_alist(ref, kref, vref)
       conn.do("insert into alist values (?, ?, ?)", ref, kref, vref)
     end
+
+    def alloc_ruby_object(klass, ref)
+      obj = klass.allocate
+      all_attr(ref).each do |sym, value|
+        next unless sym.class == Symbol
+        name = sym.to_s
+        obj.instance_eval("#{name} = value") if name[0,1] == '@'
+      end
+      obj
+    end
     
     def prop_to_obj(ref, klass, value)
       return true if ref == true.__id__
@@ -851,14 +866,18 @@ SQL
       when "String"
 	return value
       when "PRb::PRbList"
-	return PRbList.new(self, ref)
+	return PRbList.prb_new(self, ref)
       when "PRb::PRbAlist"
-	return PRbAlist.new(self, ref)
+	return PRbAlist.prb_new(self, ref)
       when /.+/
 	v = prim_load(klass, value)
 	return v if v
 	k = eval(klass)
-	return k.new(self, ref)
+        if k.ancestors.include?(PRbObject)
+          return k.prb_new(self, ref)
+        else
+          return alloc_ruby_object(k, ref)
+        end
       end
     end
     
@@ -897,6 +916,15 @@ SQL
 	  alloc_alist(ref, kref, vref)
 	end
       end
+
+      unless primitive?(obj)
+        obj.instance_variables.each do |name|
+          kref = ref_walk(name.intern, map)
+          vref = ref_walk(obj.instance_eval(name), map)
+	  alloc_alist(ref, kref, vref)
+        end
+      end
+
       return ref
     end
   end
