@@ -45,9 +45,9 @@ module PRbSign
   end
 
   class GuestBook < PRb::PRbObject
-    def init
-      self.signbook = SignBook.knew
-      self.user = PRb::PRbAttr.knew
+    def initialize
+      self.signbook = SignBook.new
+      self.user = PRb::PRbAttr.new
     end
     prb_attr :signbook, :user
     
@@ -61,7 +61,7 @@ module PRbSign
     def add_user(name, phrase)
       transaction do
 	self.signbook.set_sign(name, nil, phrase)
-	guest = PRb::PRbAttr.knew
+	guest = PRb::PRbAttr.new
 	guest[:name] = name
 	self.user[name] = guest
 	guest
