@@ -1,8 +1,7 @@
 require 'prb/prb'
-require 'prb/opt'
 
 def main
-  n, db, user, pw = DBIPool::check_options(ARGV)
+  n, db, user, pw = DBIPool::check_options(ARGV, opt={:db=>'DBI:Pg:prb'})
 
   if /^DBI:Pg:(.+)$/ =~ db
     system("dropdb #{$1}")
